summaryrefslogtreecommitdiffstats
path: root/src/engine/OSCClientSender.cpp
diff options
context:
space:
mode:
authorDavid Robillard <d@drobilla.net>2009-05-12 21:58:35 +0000
committerDavid Robillard <d@drobilla.net>2009-05-12 21:58:35 +0000
commited1032ca54a55c48d2f7c9709b77a4f4da935e99 (patch)
treeebc821e22bcdd9424383174fe9ec2a6a32dbb362 /src/engine/OSCClientSender.cpp
parentc32745b044d88e74526599c5994255a2ea6d2c21 (diff)
downloadingen-ed1032ca54a55c48d2f7c9709b77a4f4da935e99.tar.gz
ingen-ed1032ca54a55c48d2f7c9709b77a4f4da935e99.tar.bz2
ingen-ed1032ca54a55c48d2f7c9709b77a4f4da935e99.zip
Bring EngineInterface and ClientInterface closer together.
git-svn-id: http://svn.drobilla.net/lad/trunk/ingen@1990 a436a847-0d15-0410-975c-d299462d15a1
Diffstat (limited to 'src/engine/OSCClientSender.cpp')
-rw-r--r--src/engine/OSCClientSender.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/engine/OSCClientSender.cpp b/src/engine/OSCClientSender.cpp
index 2e058ed5..1357258e 100644
--- a/src/engine/OSCClientSender.cpp
+++ b/src/engine/OSCClientSender.cpp
@@ -175,13 +175,13 @@ OSCClientSender::destroy(const std::string& path)
/** \page client_osc_namespace
* <p> \b /ingen/patch_cleared - Notification a patch has been cleared (all children destroyed)
* \arg \b path (string) - Path of patch (which is now empty)</p> \n \n
*/
void
-OSCClientSender::patch_cleared(const std::string& patch_path)
+OSCClientSender::clear_patch(const std::string& patch_path)
{
- send("/ingen/patch_cleared", "s", patch_path.c_str(), LO_ARGS_END);
+ send("/ingen/clear_patch", "s", patch_path.c_str(), LO_ARGS_END);
}
@@ -350,14 +350,14 @@ OSCClientSender::new_patch(const std::string& path, uint32_t poly)
/** \page client_osc_namespace
* <p> \b /ingen/object_renamed - Notification of an object's renaming
* \arg \b old-path (string) - Old path of object
* \arg \b new-path (string) - New path of object </p> \n \n
*/
void
-OSCClientSender::object_renamed(const std::string& old_path, const std::string& new_path)
+OSCClientSender::rename(const std::string& old_path, const std::string& new_path)
{
- send("/ingen/object_renamed", "ss", old_path.c_str(), new_path.c_str(), LO_ARGS_END);
+ send("/ingen/rename", "ss", old_path.c_str(), new_path.c_str(), LO_ARGS_END);
}
@@ -175,13 +175,13 @@ OSCClientSender::destroy(const std::string& path)
/** \page client_osc_namespace
- * <p> \b /ingen/patch_cleared - Notification a patch has been cleared (all children destroyed)
+ * <p> \b /ingen/clear_patch - Notification a patch has been cleared (all children destroyed)
* \arg \b path (string) - Path of patch (which is now empty)</p> \n \n
*/
@@ -350,14 +350,14 @@ OSCClientSender::new_patch(const std::string& path, uint32_t poly)
/** \page client_osc_namespace
- * <p> \b /ingen/object_renamed - Notification of an object's renaming
+ * <p> \b /ingen/rename - Notification of an object's renaming
* \arg \b old-path (string) - Old path of object
* \arg \b new-path (string) - New path of object </p> \n \n